@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::NullOutput;
 
-our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-06-29'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,6 +15,7 @@ our $scenario = {
         'Log::ger::Plugin::OptAway' => {},
         'Log::Any' => {},
         'Log::Fast' => {},
+        'Log::Log4perl' => {},
     },
     participants => [
         {
@@ -63,6 +64,17 @@ our $scenario = {
             name => 'Log::Any-null_adapter-1mil_is_trace' ,
             perl_cmdline_template => ['-MLog::Any', '-MLog::Any::Adapter', '-e', 'Log::Any::Adapter->set(q[Null]); my $log = Log::Any->get_logger; for(1..1_000_000) { $log->is_trace }'],
         },
+
+        {
+            name => 'Log::Log4perl-easy-1mil_trace' ,
+            perl_cmdline_template => ['-MLog::Log4perl=:easy', '-e', 'Log::Log4perl->easy_init($ERROR); for(1..1_000_000) { TRACE "" }'],
+        },
+
+        {
+            name => 'Log::Log4perl::Tiny-1mil_trace' ,
+            perl_cmdline_template => ['-MLog::Log4perl::Tiny=:easy', '-e', 'for(1..1_000_000) { TRACE "" }'],
+        },
+
     ],
     precision => 6,
 };
@@ -82,7 +94,7 @@ Bencher::Scenario::LogGer::NullOutput - Benchmark Log::ger logging speed with th
 
 =head1 VERSION
 
-This document describes version 0.006 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-28.
+This document describes version 0.007 of Bencher::Scenario::LogGer::NullOutput (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-29.
 
 =head1 SYNOPSIS
 
@@ -104,6 +116,8 @@ L<Log::Any> 1.045
 
 L<Log::Fast> v2.0.0
 
+L<Log::Log4perl> 1.47
+
 L<Log::ger> 0.010
 
 L<Log::ger::Plugin::OptAway> 0.003
@@ -202,6 +216,22 @@ Command line:
 
 
 
+=item * Log::Log4perl-easy-1mil_trace (command)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::Log4perl=:easy -e Log::Log4perl->easy_init($ERROR); for(1..1_000_000) { TRACE "" }
+
+
+
+=item * Log::Log4perl::Tiny-1mil_trace (command)
+
+Command line:
+
+ #TEMPLATE: #perl -MLog::Log4perl::Tiny=:easy -e for(1..1_000_000) { TRACE "" }
+
+
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
@@ -211,21 +241,23 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m LogGer::NullOutput >>):
 
  #table1#
- +---------------------------------------+-----------+-----------+------------+---------+---------+
- | participant                           | rate (/s) | time (ms) | vs_slowest |  errors | samples |
- +---------------------------------------+-----------+-----------+------------+---------+---------+
- | Log::ger+LGP:SingleLog-1mil_log_6     |      1.8  |       560 |       1    | 0.0016  |       6 |
- | Log::ger+LGP:SingleLog-1mil_log_trace |      2    |       510 |       1.1  | 0.00089 |       7 |
- | Log::Any-null_adapter-1mil_log_trace  |      2.46 |       407 |       1.37 | 0.00031 |       6 |
- | Log::Fast-1mil_is_debug               |      3.32 |       301 |       1.85 | 0.00014 |       8 |
- | Log::Any-null_adapter-1mil_is_trace   |      4    |       250 |       2.2  | 0.0011  |       6 |
- | Log::Any-no_adapter-1mil_is_trace     |      4.1  |       250 |       2.3  | 0.0011  |       9 |
- | Log::Any-no_adapter-1mil_log_trace    |     11    |        93 |       6    | 0.00072 |       6 |
- | Log::Fast-1mil_DEBUG                  |     11    |        91 |       6.1  | 0.00035 |       6 |
- | Log::ger-1mil_log_is_trace            |     16    |        61 |       9.1  | 0.0003  |       6 |
- | Log::ger-1mil_log_trace               |     18    |        56 |       9.9  | 0.00021 |       7 |
- | Log::ger+LGP:OptAway-1mil_log_trace   |     35    |        28 |      20    | 0.00019 |       7 |
- +---------------------------------------+-----------+-----------+------------+---------+---------+
+ +---------------------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                           | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +---------------------------------------+-----------+-----------+------------+-----------+---------+
+ | Log::Log4perl::Tiny-1mil_trace        |       1.4 |     710   |        1   |   0.0025  |       7 |
+ | Log::ger+LGP:SingleLog-1mil_log_6     |       1.8 |     570   |        1.3 |   0.0033  |       7 |
+ | Log::ger+LGP:SingleLog-1mil_log_trace |       1.9 |     520   |        1.4 |   0.0012  |       6 |
+ | Log::Any-null_adapter-1mil_log_trace  |       2.4 |     420   |        1.7 |   0.0013  |       6 |
+ | Log::Fast-1mil_is_debug               |       3.2 |     310   |        2.3 |   0.0024  |       6 |
+ | Log::Any-no_adapter-1mil_is_trace     |       4.1 |     250   |        2.9 |   0.00065 |       6 |
+ | Log::Any-null_adapter-1mil_is_trace   |       4.1 |     240   |        2.9 |   0.0011  |       7 |
+ | Log::Log4perl-easy-1mil_trace         |       5.5 |     180   |        3.9 |   0.0012  |       6 |
+ | Log::Any-no_adapter-1mil_log_trace    |      11   |      95   |        7.5 |   0.00036 |       6 |
+ | Log::Fast-1mil_DEBUG                  |      11   |      92   |        7.8 |   0.00016 |       7 |
+ | Log::ger-1mil_log_is_trace            |      16   |      63   |       11   |   0.00042 |       6 |
+ | Log::ger-1mil_log_trace               |      17.5 |      57.1 |       12.5 | 3.8e-05   |       6 |
+ | Log::ger+LGP:OptAway-1mil_log_trace   |      35   |      28   |       25   | 7.9e-05   |       6 |
+ +---------------------------------------+-----------+-----------+------------+-----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
