@@ -1,7 +1,7 @@
 package Bencher::Scenario::LogGer::OutputStartup;
 
-our $DATE = '2017-06-28'; # DATE
-our $VERSION = '0.006'; # VERSION
+our $DATE = '2017-06-29'; # DATE
+our $VERSION = '0.007'; # VERSION
 
 use 5.010001;
 use strict;
@@ -70,7 +70,7 @@ Bencher::Scenario::LogGer::OutputStartup
 
 =head1 VERSION
 
-This document describes version 0.006 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-28.
+This document describes version 0.007 of Bencher::Scenario::LogGer::OutputStartup (from Perl distribution Bencher-Scenarios-LogGer), released on 2017-06-29.
 
 =head1 SYNOPSIS
 
@@ -277,35 +277,35 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (
 Benchmark with default options (C<< bencher -m LogGer::OutputStartup >>):
 
  #table1#
- +-----------------------------+-----------+-----------+------------+----------+---------+
- | participant                 | rate (/s) | time (ms) | vs_slowest |  errors  | samples |
- +-----------------------------+-----------+-----------+------------+----------+---------+
- | init-with-FileWriteRotate   |        33 |     30    |        1   | 7.6e-05  |      20 |
- | init-with-LogDispatchOutput |        55 |     18    |        1.7 |   6e-05  |      21 |
- | init-with-Composite         |        78 |     13    |        2.4 |   0.0001 |      23 |
- | init-with-LogAny            |        79 |     13    |        2.4 | 3.9e-05  |      20 |
- | init-with-DirWriteRotate    |        95 |     11    |        2.9 | 4.5e-05  |      20 |
- | init-with-Array             |       130 |      7.6  |        4   | 4.3e-05  |      20 |
- | init-with-Null              |       130 |      7.6  |        4   | 1.5e-05  |      22 |
- | init-with-ArrayWithLimits   |       130 |      7.5  |        4.1 | 4.2e-05  |      20 |
- | init-with-Callback          |       130 |      7.5  |        4.1 | 1.5e-05  |      21 |
- | init-with-String            |       130 |      7.4  |        4.1 | 2.5e-05  |      22 |
- | init-with-File              |       130 |      7.4  |        4.1 | 3.9e-05  |      22 |
- | init-with-Screen            |       140 |      7.4  |        4.1 | 3.7e-05  |      20 |
- | load-LogDispatchOutput      |       160 |      6.3  |        4.8 |   2e-05  |      20 |
- | load-Composite              |       200 |      5    |        6.1 | 2.6e-05  |      20 |
- | load-Callback               |       210 |      4.8  |        6.3 | 3.4e-05  |      20 |
- | load-LogAny                 |       210 |      4.8  |        6.3 | 2.3e-05  |      21 |
- | load-Screen                 |       210 |      4.8  |        6.4 | 3.4e-05  |      20 |
- | load-FileWriteRotate        |       210 |      4.7  |        6.5 | 3.1e-05  |      21 |
- | load-File                   |       210 |      4.7  |        6.5 | 1.9e-05  |      20 |
- | load-String                 |       210 |      4.7  |        6.5 | 1.9e-05  |      23 |
- | load-Array                  |       220 |      4.6  |        6.6 | 2.5e-05  |      20 |
- | load-DirWriteRotate         |       220 |      4.5  |        6.7 | 1.2e-05  |      20 |
- | load-ArrayWithLimits        |       230 |      4.4  |        6.9 |   2e-05  |      20 |
- | load-Null                   |       320 |      3.1  |        9.9 | 1.1e-05  |      20 |
- | baseline                    |       367 |      2.73 |       11.2 | 2.7e-06  |      20 |
- +-----------------------------+-----------+-----------+------------+----------+---------+
+ +-----------------------------+-----------+-----------+------------+-----------+---------+
+ | participant                 | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
+ +-----------------------------+-----------+-----------+------------+-----------+---------+
+ | init-with-FileWriteRotate   |        32 |      31   |        1   |   0.00014 |      20 |
+ | init-with-LogDispatchOutput |        55 |      18   |        1.7 |   4e-05   |      20 |
+ | init-with-Composite         |        75 |      13   |        2.4 | 4.2e-05   |      20 |
+ | init-with-LogAny            |        77 |      13   |        2.4 | 5.4e-05   |      23 |
+ | init-with-DirWriteRotate    |        93 |      11   |        2.9 | 1.8e-05   |      20 |
+ | init-with-String            |       100 |       8   |        4   |   0.00013 |      20 |
+ | init-with-Callback          |       130 |       7.6 |        4.2 | 2.2e-05   |      20 |
+ | init-with-File              |       130 |       7.6 |        4.2 | 3.8e-05   |      20 |
+ | init-with-Screen            |       140 |       7.3 |        4.3 | 2.3e-05   |      21 |
+ | init-with-Null              |       140 |       7.2 |        4.4 | 1.9e-05   |      20 |
+ | init-with-ArrayWithLimits   |       140 |       7.2 |        4.4 |   2e-05   |      22 |
+ | init-with-Array             |       140 |       7.2 |        4.4 | 2.9e-05   |      20 |
+ | load-LogDispatchOutput      |       160 |       6.3 |        5   | 3.4e-05   |      20 |
+ | load-File                   |       190 |       5.1 |        6.1 | 4.9e-05   |      20 |
+ | load-Composite              |       200 |       5   |        6.3 | 1.7e-05   |      20 |
+ | load-ArrayWithLimits        |       200 |       5   |        6   | 6.7e-05   |      20 |
+ | load-Callback               |       210 |       4.8 |        6.6 | 2.8e-05   |      20 |
+ | load-String                 |       210 |       4.7 |        6.7 | 2.5e-05   |      20 |
+ | load-DirWriteRotate         |       210 |       4.7 |        6.7 | 2.5e-05   |      20 |
+ | load-LogAny                 |       210 |       4.7 |        6.7 | 3.2e-05   |      20 |
+ | load-Screen                 |       210 |       4.7 |        6.8 | 2.4e-05   |      20 |
+ | load-FileWriteRotate        |       220 |       4.6 |        6.8 | 1.6e-05   |      20 |
+ | load-Array                  |       220 |       4.6 |        6.8 | 2.3e-05   |      20 |
+ | load-Null                   |       330 |       3   |       10   | 1.9e-05   |      21 |
+ | baseline                    |       350 |       2.8 |       11   | 1.6e-05   |      22 |
+ +-----------------------------+-----------+-----------+------------+-----------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module-startup >>):
@@ -314,19 +314,19 @@ Benchmark module startup overhead (C<< bencher -m LogGer::OutputStartup --module
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
  | participant                         | proc_private_dirty_size (kB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Log::ger::Output::LogDispatchOutput | 852                          | 4.1                | 20             |       6.4 |                    3.5 |        1   | 1.6e-05 |      20 |
- | Log::ger::Output::Composite         | 856                          | 4.1                | 20             |       5.1 |                    2.2 |        1.2 | 2.9e-05 |      20 |
- | Log::ger::Output::LogAny            | 956                          | 4.2                | 20             |       4.9 |                    2   |        1.3 | 3.5e-05 |      22 |
- | Log::ger::Output::DirWriteRotate    | 856                          | 4.1                | 20             |       4.9 |                    2   |        1.3 | 2.9e-05 |      20 |
- | Log::ger::Output::File              | 856                          | 4.1                | 20             |       4.9 |                    2   |        1.3 | 3.2e-05 |      20 |
- | Log::ger::Output::FileWriteRotate   | 960                          | 4.2                | 20             |       4.8 |                    1.9 |        1.3 | 3.8e-05 |      20 |
- | Log::ger::Output::ArrayWithLimits   | 848                          | 4.1                | 20             |       4.7 |                    1.8 |        1.3 | 3.5e-05 |      20 |
- | Log::ger::Output::Callback          | 852                          | 4.1                | 20             |       4.7 |                    1.8 |        1.3 |   3e-05 |      20 |
- | Log::ger::Output::String            | 856                          | 4.1                | 20             |       4.7 |                    1.8 |        1.4 | 1.5e-05 |      20 |
- | Log::ger::Output::Array             | 848                          | 4.1                | 20             |       4.6 |                    1.7 |        1.4 | 1.8e-05 |      20 |
- | Log::ger::Output::Screen            | 856                          | 4.1                | 20             |       4.6 |                    1.7 |        1.4 | 1.6e-05 |      20 |
- | Log::ger::Output::Null              | 852                          | 4.1                | 20             |       3.1 |                    0.2 |        2   | 1.6e-05 |      20 |
- | perl -e1 (baseline)                 | 836                          | 4.1                | 20             |       2.9 |                    0   |        2.2 | 7.8e-06 |      20 |
+ | Log::ger::Output::LogDispatchOutput | 852                          | 4.1                | 20             |       6.5 |                    3.6 |        1   | 1.4e-05 |      20 |
+ | Log::ger::Output::Composite         | 848                          | 4.1                | 20             |       5.1 |                    2.2 |        1.3 | 9.6e-06 |      20 |
+ | Log::ger::Output::Screen            | 856                          | 4.1                | 20             |       4.9 |                    2   |        1.3 | 2.4e-05 |      20 |
+ | Log::ger::Output::String            | 852                          | 4.2                | 20             |       4.8 |                    1.9 |        1.3 | 3.7e-05 |      20 |
+ | Log::ger::Output::Array             | 844                          | 4.1                | 20             |       4.8 |                    1.9 |        1.4 | 1.8e-05 |      23 |
+ | Log::ger::Output::ArrayWithLimits   | 844                          | 4.1                | 20             |       4.7 |                    1.8 |        1.4 | 1.5e-05 |      20 |
+ | Log::ger::Output::LogAny            | 952                          | 4.2                | 20             |       4.7 |                    1.8 |        1.4 | 1.8e-05 |      20 |
+ | Log::ger::Output::Callback          | 848                          | 4.1                | 20             |       4.7 |                    1.8 |        1.4 | 2.3e-05 |      20 |
+ | Log::ger::Output::FileWriteRotate   | 952                          | 4.2                | 20             |       4.5 |                    1.6 |        1.4 | 2.6e-05 |      20 |
+ | Log::ger::Output::File              | 852                          | 4.1                | 20             |       4.5 |                    1.6 |        1.4 | 1.4e-05 |      20 |
+ | Log::ger::Output::DirWriteRotate    | 852                          | 4.1                | 20             |       4.4 |                    1.5 |        1.5 | 1.1e-05 |      20 |
+ | Log::ger::Output::Null              | 848                          | 4.2                | 20             |       3.2 |                    0.3 |        2   | 1.3e-05 |      20 |
+ | perl -e1 (baseline)                 | 836                          | 4.1                | 20             |       2.9 |                    0   |        2.2 | 1.3e-05 |      20 |
  +-------------------------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
