@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.006; # VERSION
+our $VERSION = 0.007; # VERSION
 
 our $results = [
   [
@@ -8,92 +8,108 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0016,
-        participant => "Log::ger+LGP:SingleLog-1mil_log_6",
-        rate => 1.8,
-        samples => 6,
-        time => 560,
+        errors => 0.0025,
+        participant => "Log::Log4perl::Tiny-1mil_trace",
+        rate => 1.4,
+        samples => 7,
+        time => 710,
         vs_slowest => 1,
       },
       {
-        errors => 0.00089,
-        participant => "Log::ger+LGP:SingleLog-1mil_log_trace",
-        rate => 2,
+        errors => 0.0033,
+        participant => "Log::ger+LGP:SingleLog-1mil_log_6",
+        rate => 1.8,
         samples => 7,
-        time => 510,
-        vs_slowest => 1.1,
+        time => 570,
+        vs_slowest => 1.3,
       },
       {
-        errors => 0.00031,
-        participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 2.46,
+        errors => 0.0012,
+        participant => "Log::ger+LGP:SingleLog-1mil_log_trace",
+        rate => 1.9,
         samples => 6,
-        time => 407,
-        vs_slowest => 1.37,
+        time => 520,
+        vs_slowest => 1.4,
       },
       {
-        errors => 0.00014,
+        errors => 0.0013,
+        participant => "Log::Any-null_adapter-1mil_log_trace",
+        rate => 2.4,
+        samples => 6,
+        time => 420,
+        vs_slowest => 1.7,
+      },
+      {
+        errors => 0.0024,
         participant => "Log::Fast-1mil_is_debug",
-        rate => 3.32,
-        samples => 8,
-        time => 301,
-        vs_slowest => 1.85,
+        rate => 3.2,
+        samples => 6,
+        time => 310,
+        vs_slowest => 2.3,
+      },
+      {
+        errors => 0.00065,
+        participant => "Log::Any-no_adapter-1mil_is_trace",
+        rate => 4.1,
+        samples => 6,
+        time => 250,
+        vs_slowest => 2.9,
       },
       {
         errors => 0.0011,
         participant => "Log::Any-null_adapter-1mil_is_trace",
-        rate => 4,
-        samples => 6,
-        time => 250,
-        vs_slowest => 2.2,
-      },
-      {
-        errors => 0.0011,
-        participant => "Log::Any-no_adapter-1mil_is_trace",
         rate => 4.1,
-        samples => 9,
-        time => 250,
-        vs_slowest => 2.3,
+        samples => 7,
+        time => 240,
+        vs_slowest => 2.9,
       },
       {
-        errors => 0.00072,
+        errors => 0.0012,
+        participant => "Log::Log4perl-easy-1mil_trace",
+        rate => 5.5,
+        samples => 6,
+        time => 180,
+        vs_slowest => 3.9,
+      },
+      {
+        errors => 0.00036,
         participant => "Log::Any-no_adapter-1mil_log_trace",
         rate => 11,
         samples => 6,
-        time => 93,
-        vs_slowest => 6,
+        time => 95,
+        vs_slowest => 7.5,
       },
       {
-        errors => 0.00035,
+        errors => 0.00016,
         participant => "Log::Fast-1mil_DEBUG",
         rate => 11,
-        samples => 6,
-        time => 91,
-        vs_slowest => 6.1,
+        samples => 7,
+        time => 92,
+        vs_slowest => 7.8,
       },
       {
-        errors => 0.0003,
+        errors => 0.00042,
         participant => "Log::ger-1mil_log_is_trace",
         rate => 16,
         samples => 6,
-        time => 61,
-        vs_slowest => 9.1,
+        time => 63,
+        vs_slowest => 11,
       },
       {
-        errors => 0.00021,
+        errors => 3.8e-05,
         participant => "Log::ger-1mil_log_trace",
-        rate => 18,
-        samples => 7,
-        time => 56,
-        vs_slowest => 9.9,
+        rate => 17.5,
+        samples => 6,
+        time => 57.1,
+        vs_slowest => 12.5,
       },
       {
-        errors => 0.00019,
+        errors => 7.9e-05,
         participant => "Log::ger+LGP:OptAway-1mil_log_trace",
         rate => 35,
-        samples => 7,
+        samples => 6,
         time => 28,
-        vs_slowest => 20,
+        vs_slowest => 25,
       },
     ],
     {
@@ -211,7 +227,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3852.359,
+                                              speed                        => 3853.289,
                                               stepping                     => 3,
                                             },
                                             {
@@ -321,7 +337,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3899.507,
+                                              speed                        => "3863.250",
                                               stepping                     => 3,
                                             },
                                             {
@@ -431,7 +447,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => "3857.140",
+                                              speed                        => "3858.070",
                                               stepping                     => 3,
                                             },
                                             {
@@ -541,7 +557,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3894.992,
+                                              speed                        => 3871.617,
                                               stepping                     => 3,
                                             },
                                             {
@@ -651,7 +667,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3867.234,
+                                              speed                        => 3899.109,
                                               stepping                     => 3,
                                             },
                                             {
@@ -761,7 +777,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3897.382,
+                                              speed                        => 3819.156,
                                               stepping                     => 3,
                                             },
                                             {
@@ -871,7 +887,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3896.187,
+                                              speed                        => 3894.992,
                                               stepping                     => 3,
                                             },
                                             {
@@ -981,11 +997,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3899.773,
+                                              speed                        => 3897.914,
                                               stepping                     => 3,
                                             },
                                           ],
-      "func.elapsed_time"              => 22.9662201404572,
+      "func.elapsed_time"              => 28.0056719779968,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.036,
@@ -997,11 +1013,12 @@ our $results = [
                                             "Log::ger" => "0.010",
                                             "Log::ger::Plugin::OptAway" => 0.003,
                                             "Log::ger::Plugin::SingleLog" => 0.001,
+                                            "Log::Log4perl" => 1.47,
                                             "perl" => "v5.24.0",
                                             "Sys::Info" => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 10]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 12]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "jessie",
@@ -1027,13 +1044,13 @@ our $results = [
                                           },
       "func.precision"                 => 6,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::NullOutput",
-      "func.scenario_module_md5sum"    => "a6b4170da4821bd0a4aad87d3c5d6e4d",
-      "func.scenario_module_mtime"     => 1498617728,
-      "func.scenario_module_sha1sum"   => "86c401a2f74f7535da7939b4d02d62253daa466d",
-      "func.scenario_module_sha256sum" => "33f00ccec140f03f9d2b6934be767c54a0f37f825351316ea739e6ab3c4552af",
-      "func.time_end"                  => 1498617887.96358,
+      "func.scenario_module_md5sum"    => "3a073fe37abbe6be154ceb3b3b794a94",
+      "func.scenario_module_mtime"     => 1498692581,
+      "func.scenario_module_sha1sum"   => "c3cd9a21cb919c7795f40710cf863100a3b44dc7",
+      "func.scenario_module_sha256sum" => "44ff813f86ead98086b56295ac1d56dacbc20bd21b34f170d270e1357e58c92f",
+      "func.time_end"                  => 1498692747.02932,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498617864.99736,
+      "func.time_start"                => 1498692719.02365,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
