@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::OutputStartup;
 
-our $VERSION = 0.006; # VERSION
+our $VERSION = 0.007; # VERSION
 
 our $results = [
   [
@@ -8,204 +8,204 @@ our $results = [
     "OK",
     [
       {
-        errors => 7.6e-05,
+        errors => 0.00014,
         participant => "init-with-FileWriteRotate",
-        rate => 33,
+        rate => 32,
         samples => 20,
-        time => 30,
+        time => 31,
         vs_slowest => 1,
       },
       {
-        errors => 6e-05,
+        errors => 4e-05,
         participant => "init-with-LogDispatchOutput",
         rate => 55,
-        samples => 21,
+        samples => 20,
         time => 18,
         vs_slowest => 1.7,
       },
       {
-        errors => 0.0001,
+        errors => 4.2e-05,
         participant => "init-with-Composite",
-        rate => 78,
+        rate => 75,
+        samples => 20,
+        time => 13,
+        vs_slowest => 2.4,
+      },
+      {
+        errors => 5.4e-05,
+        participant => "init-with-LogAny",
+        rate => 77,
         samples => 23,
         time => 13,
         vs_slowest => 2.4,
       },
       {
-        errors => 3.9e-05,
-        participant => "init-with-LogAny",
-        rate => 79,
-        samples => 20,
-        time => 13,
-        vs_slowest => 2.4,
-      },
-      {
-        errors => 4.5e-05,
+        errors => 1.8e-05,
         participant => "init-with-DirWriteRotate",
-        rate => 95,
+        rate => 93,
         samples => 20,
         time => 11,
         vs_slowest => 2.9,
       },
       {
-        errors => 4.3e-05,
-        participant => "init-with-Array",
-        rate => 130,
+        errors => 0.00013,
+        participant => "init-with-String",
+        rate => 100,
         samples => 20,
-        time => 7.6,
+        time => 8,
         vs_slowest => 4,
       },
       {
-        errors => 1.5e-05,
-        participant => "init-with-Null",
-        rate => 130,
-        samples => 22,
-        time => 7.6,
-        vs_slowest => 4,
-      },
-      {
-        errors => 4.2e-05,
-        participant => "init-with-ArrayWithLimits",
-        rate => 130,
-        samples => 20,
-        time => 7.5,
-        vs_slowest => 4.1,
-      },
-      {
-        errors => 1.5e-05,
+        errors => 2.2e-05,
         participant => "init-with-Callback",
         rate => 130,
-        samples => 21,
-        time => 7.5,
-        vs_slowest => 4.1,
+        samples => 20,
+        time => 7.6,
+        vs_slowest => 4.2,
       },
       {
-        errors => 2.5e-05,
-        participant => "init-with-String",
-        rate => 130,
-        samples => 22,
-        time => 7.4,
-        vs_slowest => 4.1,
-      },
-      {
-        errors => 3.9e-05,
+        errors => 3.8e-05,
         participant => "init-with-File",
         rate => 130,
-        samples => 22,
-        time => 7.4,
-        vs_slowest => 4.1,
+        samples => 20,
+        time => 7.6,
+        vs_slowest => 4.2,
       },
       {
-        errors => 3.7e-05,
+        errors => 2.3e-05,
         participant => "init-with-Screen",
         rate => 140,
+        samples => 21,
+        time => 7.3,
+        vs_slowest => 4.3,
+      },
+      {
+        errors => 1.9e-05,
+        participant => "init-with-Null",
+        rate => 140,
         samples => 20,
-        time => 7.4,
-        vs_slowest => 4.1,
+        time => 7.2,
+        vs_slowest => 4.4,
       },
       {
         errors => 2e-05,
+        participant => "init-with-ArrayWithLimits",
+        rate => 140,
+        samples => 22,
+        time => 7.2,
+        vs_slowest => 4.4,
+      },
+      {
+        errors => 2.9e-05,
+        participant => "init-with-Array",
+        rate => 140,
+        samples => 20,
+        time => 7.2,
+        vs_slowest => 4.4,
+      },
+      {
+        errors => 3.4e-05,
         participant => "load-LogDispatchOutput",
         rate => 160,
         samples => 20,
         time => 6.3,
-        vs_slowest => 4.8,
+        vs_slowest => 5,
       },
       {
-        errors => 2.6e-05,
+        errors => 4.9e-05,
+        participant => "load-File",
+        rate => 190,
+        samples => 20,
+        time => 5.1,
+        vs_slowest => 6.1,
+      },
+      {
+        errors => 1.7e-05,
         participant => "load-Composite",
         rate => 200,
         samples => 20,
         time => 5,
-        vs_slowest => 6.1,
+        vs_slowest => 6.3,
       },
       {
-        errors => 3.4e-05,
+        errors => 6.7e-05,
+        participant => "load-ArrayWithLimits",
+        rate => 200,
+        samples => 20,
+        time => 5,
+        vs_slowest => 6,
+      },
+      {
+        errors => 2.8e-05,
         participant => "load-Callback",
         rate => 210,
         samples => 20,
         time => 4.8,
-        vs_slowest => 6.3,
-      },
-      {
-        errors => 2.3e-05,
-        participant => "load-LogAny",
-        rate => 210,
-        samples => 21,
-        time => 4.8,
-        vs_slowest => 6.3,
-      },
-      {
-        errors => 3.4e-05,
-        participant => "load-Screen",
-        rate => 210,
-        samples => 20,
-        time => 4.8,
-        vs_slowest => 6.4,
-      },
-      {
-        errors => 3.1e-05,
-        participant => "load-FileWriteRotate",
-        rate => 210,
-        samples => 21,
-        time => 4.7,
-        vs_slowest => 6.5,
-      },
-      {
-        errors => 1.9e-05,
-        participant => "load-File",
-        rate => 210,
-        samples => 20,
-        time => 4.7,
-        vs_slowest => 6.5,
-      },
-      {
-        errors => 1.9e-05,
-        participant => "load-String",
-        rate => 210,
-        samples => 23,
-        time => 4.7,
-        vs_slowest => 6.5,
+        vs_slowest => 6.6,
       },
       {
         errors => 2.5e-05,
+        participant => "load-String",
+        rate => 210,
+        samples => 20,
+        time => 4.7,
+        vs_slowest => 6.7,
+      },
+      {
+        errors => 2.5e-05,
+        participant => "load-DirWriteRotate",
+        rate => 210,
+        samples => 20,
+        time => 4.7,
+        vs_slowest => 6.7,
+      },
+      {
+        errors => 3.2e-05,
+        participant => "load-LogAny",
+        rate => 210,
+        samples => 20,
+        time => 4.7,
+        vs_slowest => 6.7,
+      },
+      {
+        errors => 2.4e-05,
+        participant => "load-Screen",
+        rate => 210,
+        samples => 20,
+        time => 4.7,
+        vs_slowest => 6.8,
+      },
+      {
+        errors => 1.6e-05,
+        participant => "load-FileWriteRotate",
+        rate => 220,
+        samples => 20,
+        time => 4.6,
+        vs_slowest => 6.8,
+      },
+      {
+        errors => 2.3e-05,
         participant => "load-Array",
         rate => 220,
         samples => 20,
         time => 4.6,
-        vs_slowest => 6.6,
+        vs_slowest => 6.8,
       },
       {
-        errors => 1.2e-05,
-        participant => "load-DirWriteRotate",
-        rate => 220,
-        samples => 20,
-        time => 4.5,
-        vs_slowest => 6.7,
-      },
-      {
-        errors => 2e-05,
-        participant => "load-ArrayWithLimits",
-        rate => 230,
-        samples => 20,
-        time => 4.4,
-        vs_slowest => 6.9,
-      },
-      {
-        errors => 1.1e-05,
+        errors => 1.9e-05,
         participant => "load-Null",
-        rate => 320,
-        samples => 20,
-        time => 3.1,
-        vs_slowest => 9.9,
+        rate => 330,
+        samples => 21,
+        time => 3,
+        vs_slowest => 10,
       },
       {
-        errors => 2.7e-06,
+        errors => 1.6e-05,
         participant => "baseline",
-        rate => 367,
-        samples => 20,
-        time => 2.73,
-        vs_slowest => 11.2,
+        rate => 350,
+        samples => 22,
+        time => 2.8,
+        vs_slowest => 11,
       },
     ],
     {
@@ -323,7 +323,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3856.343,
+                                              speed                        => 3700.023,
                                               stepping                     => 3,
                                             },
                                             {
@@ -433,7 +433,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => 3836.953,
+                                              speed                        => 3832.304,
                                               stepping                     => 3,
                                             },
                                             {
@@ -543,7 +543,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3870.156,
+                                              speed                        => 3830.976,
                                               stepping                     => 3,
                                             },
                                             {
@@ -653,7 +653,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3884.234,
+                                              speed                        => 3794.984,
                                               stepping                     => 3,
                                             },
                                             {
@@ -763,7 +763,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => "3791.000",
+                                              speed                        => 3900.039,
                                               stepping                     => 3,
                                             },
                                             {
@@ -873,7 +873,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3801.359,
+                                              speed                        => 3867.765,
                                               stepping                     => 3,
                                             },
                                             {
@@ -983,7 +983,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => 3895.523,
+                                              speed                        => 3896.453,
                                               stepping                     => 3,
                                             },
                                             {
@@ -1093,11 +1093,11 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3899.773,
+                                              speed                        => 3873.476,
                                               stepping                     => 3,
                                             },
                                           ],
-      "func.elapsed_time"              => 5.40375208854675,
+      "func.elapsed_time"              => 5.54703211784363,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => 1.036,
@@ -1150,9 +1150,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1498449729,
       "func.scenario_module_sha1sum"   => "0389ae613ac5ab14f9accef3e8dd982546902675",
       "func.scenario_module_sha256sum" => "0a4e1e5e5c42944c030a62cb5f532fde7cdacd07c6f85077bab8c993aa51ce6f",
-      "func.time_end"                  => 1498617893.70582,
+      "func.time_end"                  => 1498692752.94014,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498617888.30206,
+      "func.time_start"                => 1498692747.39311,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
