@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::Startup;
 
-our $VERSION = 0.006; # VERSION
+our $VERSION = 0.007; # VERSION
 
 our $results = [
   [
@@ -8,85 +8,121 @@ our $results = [
     "OK",
     [
       {
-        errors      => 2.3e-05,
+        errors      => 0.0001,
         modver      => "",
-        participant => "use Log::Any + use Log::Any::Adapter::Screen",
-        rate        => 120,
+        participant => "use Log::Log4perl + easy_init",
+        rate        => 41,
         samples     => 20,
-        time        => 8.3,
+        time        => 24,
         vs_slowest  => 1,
       },
       {
-        errors      => 3e-05,
+        errors      => 5.1e-05,
+        modver      => "",
+        participant => "use Log::Log4perl ()",
+        rate        => 42,
+        samples     => 20,
+        time        => 24,
+        vs_slowest  => 1,
+      },
+      {
+        errors      => 5.3e-05,
+        modver      => "",
+        participant => "use Log::Log4perl::Tiny ()",
+        rate        => 86,
+        samples     => 20,
+        time        => 12,
+        vs_slowest  => 2.1,
+      },
+      {
+        errors      => 3.2e-05,
+        modver      => "",
+        participant => "use Log::Log4perl::Tiny :easy",
+        rate        => 87,
+        samples     => 20,
+        time        => 11,
+        vs_slowest  => 2.1,
+      },
+      {
+        errors      => 4.6e-05,
+        modver      => "",
+        participant => "use Log::Any + use LGA:Screen",
+        rate        => 120,
+        samples     => 20,
+        time        => 8.4,
+        vs_slowest  => 2.9,
+      },
+      {
+        errors      => 2.2e-05,
         modver      => 1.045,
         participant => "use Log::Any",
-        rate        => 150,
-        samples     => 21,
-        time        => 6.8,
-        vs_slowest  => 1.2,
-      },
-      {
-        errors      => 1.6e-05,
-        modver      => "",
-        participant => "use Log::ger + use Log::ger::Output::Screen",
-        rate        => 190,
+        rate        => 140,
         samples     => 22,
-        time        => 5.4,
-        vs_slowest  => 1.5,
+        time        => 7,
+        vs_slowest  => 3.5,
       },
       {
-        errors      => 1.4e-05,
+        errors      => 2.8e-05,
+        modver      => "",
+        participant => "use Log::ger + use LGP:Screen",
+        rate        => 180,
+        samples     => 21,
+        time        => 5.4,
+        vs_slowest  => 4.5,
+      },
+      {
+        errors      => 1.9e-05,
         modver      => "",
         participant => "use Log::ger::Like::LogAny",
         rate        => 220,
         samples     => 20,
-        time        => 4.5,
-        vs_slowest  => 1.8,
+        time        => 4.6,
+        vs_slowest  => 5.3,
       },
       {
-        errors      => 1.4e-05,
+        errors      => 2.4e-05,
         modver      => "",
-        participant => "use Log::ger + use Log::ger::Plugin::OptAway",
-        rate        => 280,
+        participant => "use Log::ger + use LGP:OptAway",
+        rate        => 270,
         samples     => 20,
-        time        => 3.6,
-        vs_slowest  => 2.3,
+        time        => 3.7,
+        vs_slowest  => 6.6,
       },
       {
-        errors      => 1.1e-05,
+        errors      => 1.8e-05,
         modver      => 0.15,
         participant => "use Log::Any",
         rate        => 330,
         samples     => 20,
-        time        => 3,
-        vs_slowest  => 2.7,
+        time        => 3.1,
+        vs_slowest  => 7.9,
       },
       {
-        errors      => 9.1e-06,
+        errors      => 1.6e-05,
         modver      => "",
         participant => "use Log::ger",
         rate        => 460,
-        samples     => 20,
+        samples     => 21,
         time        => 2.2,
-        vs_slowest  => 3.8,
+        vs_slowest  => 11,
       },
       {
-        errors      => 1.1e-05,
+        errors      => 1.3e-05,
         modver      => "",
         participant => "use Log::ger ()",
-        rate        => 470,
+        rate        => 490,
         samples     => 20,
-        time        => 2.1,
-        vs_slowest  => 3.9,
+        time        => 2,
+        vs_slowest  => 12,
       },
       {
-        errors      => 4.5e-06,
+        errors      => 4.7e-06,
         modver      => "",
         participant => "baseline",
         rate        => 830,
         samples     => 20,
         time        => 1.2,
-        vs_slowest  => 6.8,
+        vs_slowest  => 20,
       },
     ],
     {
@@ -206,7 +242,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 0,
-                                              speed                        => 3822.875,
+                                              speed                        => 3873.742,
                                               stepping                     => 3,
                                             },
                                             {
@@ -316,7 +352,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 1,
-                                              speed                        => "3827.390",
+                                              speed                        => 3786.085,
                                               stepping                     => 3,
                                             },
                                             {
@@ -426,7 +462,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 2,
-                                              speed                        => 3792.062,
+                                              speed                        => 3899.109,
                                               stepping                     => 3,
                                             },
                                             {
@@ -536,7 +572,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 3,
-                                              speed                        => 3871.617,
+                                              speed                        => "3820.750",
                                               stepping                     => 3,
                                             },
                                             {
@@ -646,7 +682,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 4,
-                                              speed                        => 3894.195,
+                                              speed                        => 3899.242,
                                               stepping                     => 3,
                                             },
                                             {
@@ -756,7 +792,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 5,
-                                              speed                        => 3898.312,
+                                              speed                        => 3891.273,
                                               stepping                     => 3,
                                             },
                                             {
@@ -866,7 +902,7 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 6,
-                                              speed                        => "3896.320",
+                                              speed                        => 3900.039,
                                               stepping                     => 3,
                                             },
                                             {
@@ -976,33 +1012,35 @@ our $results = [
                                               number_of_cores              => 4,
                                               number_of_logical_processors => 8,
                                               processor_id                 => 7,
-                                              speed                        => 3893.664,
+                                              speed                        => 3824.601,
                                               stepping                     => 3,
                                             },
                                           ],
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__" => 1.036,
+                                            "__PACKAGE__"                        => 1.036,
                                             "Bencher::Scenario::LogGer::Startup" => undef,
-                                            "Benchmark::Dumb" => "0.10",
-                                            "Devel::Platform::Info" => 0.16,
-                                            "Log::Any" => 1.045,
-                                            "Log::Any::Adapter::Screen" => 0.13,
-                                            "Log::ger" => "0.010",
-                                            "Log::ger::Like::LogAny" => 0.001,
-                                            "Log::ger::Output::Screen" => 0.004,
-                                            "Log::ger::Plugin::OptAway" => 0.003,
-                                            "perl" => "v5.24.0",
-                                            "Sys::Info" => 0.78,
+                                            "Benchmark::Dumb"                    => "0.10",
+                                            "Devel::Platform::Info"              => 0.16,
+                                            "Log::Any"                           => 1.045,
+                                            "Log::Any::Adapter::Screen"          => 0.13,
+                                            "Log::ger"                           => "0.010",
+                                            "Log::ger::Like::LogAny"             => 0.001,
+                                            "Log::ger::Output::Screen"           => 0.004,
+                                            "Log::ger::Plugin::OptAway"          => 0.003,
+                                            "Log::Log4perl"                      => 1.47,
+                                            "Log::Log4perl::Tiny"                => "1.4.0",
+                                            "perl"                               => "v5.24.0",
+                                            "Sys::Info"                          => 0.78,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
       "func.permute"                   => [
                                             "perl",
                                             ["perl"],
                                             "modver",
-                                            [0.15, 1.045],
+                                            [1.045, 0.15],
                                             "participant",
-                                            [0 .. 7],
+                                            [0 .. 11],
                                           ],
       "func.platform_info"             => {
                                             archname => "x86_64",
@@ -1029,12 +1067,12 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::Startup",
-      "func.scenario_module_md5sum"    => "d6fa870e804242b51756b66fba8c4b7c",
-      "func.scenario_module_mtime"     => 1498617817,
-      "func.scenario_module_sha1sum"   => "54ea09103e3b6dee3aed5c6404117751cb0af292",
-      "func.scenario_module_sha256sum" => "c374a16ca36d2669c65018f688dada719a7eb2d2aa8f06624e405675dc73f712",
+      "func.scenario_module_md5sum"    => "db6c118b2679bda9798357cf63e0a75c",
+      "func.scenario_module_mtime"     => 1498692527,
+      "func.scenario_module_sha1sum"   => "b60e1f12901e37a9a19565e09c89b6ea66e5ca81",
+      "func.scenario_module_sha256sum" => "fe413bfa0c051f69740e4b2918eff86c10d2bcf5ff6c24f928606cdfc5bc0ed3",
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498617895.9954,
+      "func.time_start"                => 1498692755.30384,
       "table.field_aligns"             => [
                                             "left",
                                             "left",
@@ -1061,7 +1099,7 @@ our $results = [
 ];
 
 1;
-# ABSTRACT: 
+# ABSTRACT: Measure startup overhead of Log::ger vs other logging libraries
 
 =head1 DESCRIPTION
 
